@@ -52,12 +52,24 @@ Datasets:
 
         y: Projectile height (meters)
 
+    df_shewhart: Aluminum die cast data from Table 3 in Shewhart (1931)
+
+        specimen: Specimen identifier
+
+        tensile_strength: Specimen tensile strength (psi)
+
+        hardness: Specimen hardness (Rockwell's "E")
+
+        density: Specimen density (gm/cm^3)
+
 References:
     Stang, Greenspan, and Newman, "Poisson's ratio of some structural alloys for
     large strains" (1946) U.S. Department of Commerce National Bureau of Standards
 
     Ruff, Paul E. An Overview of the MIL-HDBK-5 Program. BATTELLE COLUMBUS DIV
     OH, 1984.
+
+    Shewhart *Economic Control of Quality of Manufactured Product* (1931) D. Van Nostrand Company, Inc.
 """
 
 from .datasets import *
