@@ -1,6 +1,13 @@
-from .base import *
-import pandas as pd
+__all__ = [
+    "var_in",
+    "is_nan",
+    "not_nan",
+]
+
+from .base import make_symbolic
 from numpy import isnan, logical_not
+from pandas import Series
+
 
 # ------------------------------------------------------------------------------
 # Mask helpers
@@ -17,7 +24,7 @@ def var_in(series, collection):
         series: column to compute inclusion bools
         collection: set for inclusion calcs
     """
-    bools = pd.Series([s in collection for s in series])
+    bools = Series([s in collection for s in series])
 
     return bools
 
@@ -38,8 +45,7 @@ def is_nan(series, inv=False):
 
     if inv:
         return logical_not(bools)
-    else:
-        return bools
+    return bools
 
 
 @make_symbolic
@@ -58,5 +64,4 @@ def not_nan(series, inv=False):
 
     if inv:
         return bools
-    else:
-        return logical_not(bools)
+    return logical_not(bools)
