@@ -1,4 +1,8 @@
 __all__ = [
+    "plot_contour",
+    "pt_contour",
+    "plot_corrtile",
+    "pt_corrtile",
     "plot_scattermat",
     "pt_scattermat",
     "plot_hists",
@@ -18,8 +22,9 @@ from pandas import melt
 
 from plotnine import aes, annotate, ggplot, facet_grid, facet_wrap, labs, element_text, guides
 from plotnine import theme, theme_void, theme_minimal
-from plotnine import scale_x_continuous, scale_y_continuous
-from plotnine import geom_point, geom_density, geom_histogram, geom_line, geom_blank
+from plotnine import scale_x_continuous, scale_y_continuous, scale_fill_gradient2
+from plotnine import geom_point, geom_density, geom_histogram, geom_line, geom_tile
+from plotnine import geom_segment, geom_blank
 from matplotlib import gridspec
 
 from toolz import curry
@@ -32,12 +37,80 @@ def _sci_format(v):
     return (
         ["{0:1.1e}".format(v[0])] +
         [""] * (len(v) - 2) +
-        ["{0:1.1e}".format(v[-1])]
+        ["\n{0:1.1e}".format(v[-1])]
     )
 
 ## Function-specific plot functions
 ##################################################
-## Monte Carlo
+## eval_contour
+@curry
+def plot_contour(df, var=None, out="out", level="level", aux=False):
+    r"""Plot 2d contours
+
+    Plot contours.
+
+    Usually called as a dispatch from plot_auto().
+
+    Args:
+        var (array of str): Variables for plot axes
+        out (str): Name of output identifier column
+        level (str): Name of level identifier column
+        aux (bool): Auxillary variables present?
+
+    Returns:
+        ggplot: Contour image
+
+    Examples:
+
+        >>> import grama as gr
+        >>> from grama.models import make_cantilever_beam
+
+    """
+    # Check invariants
+    if var is None:
+        raise ValueError("Must provide input columns list as keyword var")
+    if aux:
+        raise ValueError(
+            "Autoplot plot_contour not designed to handle auxiliary variables. " +
+            "Regenerate contour data with fixed auxilary variables, " +
+            "or try creating a manual plot."
+        )
+
+    return (
+        df
+        >> ggplot()
+        + geom_segment(
+            aes(
+                var[0],
+                var[1],
+                xend=var[0]+"_end",
+                yend=var[1]+"_end",
+                linetype=out,
+                color=level,
+            )
+        )
+    )
+
+
+pt_contour = add_pipe(plot_contour)
+
+## tran_iocorr
+# --------------------------------------------------
+@curry
+def plot_corrtile(df, var=None, out=None, corr=None):
+    r"""
+    """
+    return (
+        df
+        >> ggplot(aes(var, out))
+        + geom_tile(aes(fill=corr))
+        + scale_fill_gradient2(name="Corr", midpoint=0)
+        + theme(axis_text_x=element_text(angle=270))
+    )
+
+pt_corrtile = add_pipe(plot_corrtile)
+
+## Sample
 # --------------------------------------------------
 @curry
 def plot_scattermat(df, var=None):
@@ -52,7 +125,7 @@ def plot_scattermat(df, var=None):
         var (list of strings): Variables to plot
 
     Returns:
-        DataFrame: Results of evaluation or unevaluated design
+        ggplot: Scatterplot matrix
 
     Examples:
 
@@ -164,7 +237,7 @@ pt_scattermat = add_pipe(plot_scattermat)
 
 
 @curry
-def plot_hists(df, out=None):
+def plot_hists(df, out=None, **kwargs):
     r"""Construct histograms
 
     Create a set of histograms. Often used to visualize the results of random
@@ -416,6 +489,7 @@ def plot_sinew_outputs(
         )
         + guides(color=None)
         + theme_minimal()
+        + theme(strip_text_y=element_text(angle=0))
         + labs(
             x="Input Value",
             y="Output Value",
@@ -428,10 +502,12 @@ pt_sinew_outputs = add_pipe(plot_sinew_outputs)
 ## Autoplot dispatcher
 ## ##################################################
 plot_list = {
+    "contour": plot_contour,
     "sinew_inputs": plot_sinew_inputs,
     "sinew_outputs": plot_sinew_outputs,
     "sample_inputs": plot_scattermat,
     "sample_outputs": plot_hists,
+    "iocorr": plot_corrtile,
 }
 
 
