@@ -9,7 +9,7 @@ try:
     from matminer.featurizers.composition import ElementProperty
 
 except ModuleNotFoundError:
-    raise ModuleNotFoundError("module matminer not found")
+    pass
 
 from grama import add_pipe, pipe
 from pandas import concat
@@ -60,7 +60,18 @@ def tran_feat_composition(
     ## Check invariants
 
     ## Featurize
-    featurizer = ElementProperty.from_preset(preset_name=preset_name)
+    try:
+        featurizer = ElementProperty.from_preset(preset_name=preset_name)
+
+    except NameError as e:
+        error_string = str(e)
+        raise NameError(
+            error_string +
+            "\n\nThis function requires the `matminer` package. " +
+            "Try running the following to install the package:\n"
+            "    pip install matminer"
+        )
+
     df_res = StrToComposition().featurize_dataframe(
         df[[var_formula]], var_formula, ignore_errors=ignore_errors,
     )
