@@ -5,21 +5,12 @@ __all__ = [
     "tf_bootstrap",
     "tran_copula_corr",
     "tf_copula_corr",
-    "tran_outer",
-    "tf_outer",
     "tran_kfolds",
     "tf_kfolds",
     "tran_md",
     "tf_md",
 ]
 
-from collections import ChainMap
-from numpy import arange, ceil, zeros, std, quantile, nan, triu_indices, unique
-from numpy.random import choice, permutation
-from numpy.random import seed as set_seed
-from pandas import concat, DataFrame, melt
-from .string_helpers import str_detect, str_replace
-
 from grama import add_pipe, pipe, copy_meta, Intention, mse, rsq
 from grama import (
     tf_bind_cols,
@@ -30,15 +21,21 @@ from grama import (
     var_in,
     ev_df,
 )
-
-from toolz import curry
+from collections import ChainMap
 from numbers import Integral
+from numpy import arange, ceil, zeros, std, quantile, nan, triu_indices, unique
+from numpy.random import choice, permutation
+from numpy.random import seed as set_seed
+from pandas import concat, DataFrame, melt
 from pandas.api.types import is_numeric_dtype
 from scipy.linalg import subspace_angles
 from scipy.stats import norm
+from .string_helpers import str_detect, str_replace
+from toolz import curry
 
 X = Intention()
 
+
 ## k-Fold CV utility
 # --------------------------------------------------
 @curry
@@ -288,48 +285,6 @@ def tran_bootstrap(
 tf_bootstrap = add_pipe(tran_bootstrap)
 
 
-## DataFrame outer product
-# --------------------------------------------------
-@curry
-def tran_outer(df, df_outer):
-    r"""Outer merge
-
-    Perform an outer-merge on two dataframes.
-
-    Args:
-        df (DataFrame): Data to merge
-        df_outer (DataFrame): Data to merge; outer
-
-    Returns:
-        DataFrame: Merged data
-
-    Examples:
-        >>> import grama as gr
-        >>> import pandas as pd
-        >>> df = pd.DataFrame(dict(x=[1,2]))
-        >>> df_outer = pd.DataFrame(dict(y=[3,4]))
-        >>> df_res = gr.tran_outer(df, df_outer)
-        >>> df_res
-        >>>    x  y
-        >>> 0  1  3
-        >>> 1  2  3
-        >>> 2  1  4
-        >>> 3  2  4
-
-    """
-    n_rows = df.shape[0]
-    list_df = []
-
-    for ind in range(df_outer.shape[0]):
-        df_rep = concat([df_outer.iloc[[ind]]] * n_rows, ignore_index=True)
-        list_df.append(concat((df, df_rep), axis=1))
-
-    return concat(list_df, ignore_index=True)
-
-
-tf_outer = add_pipe(tran_outer)
-
-
 ## Assess subspace angles
 # --------------------------------------------------
 def tran_angles(df, df2):
